author_info = (("Dmitry Orlov", "me@mosquito.su"),)

package_info = "Python wrapper for libmagic"
package_license = "Apache Software License"

team_email = author_info[0][1]

version_info = (0, 3, 1)

__author__ = ", ".join("{} <{}>".format(*info) for info in author_info)
__version__ = ".".join(map(str, version_info))


__all__ = (
    "author_info",
    "package_info",
    "package_license",
    "team_email",
    "version_info",
    "__author__",
    "__version__",
)



from typing import *


# noinspection PyShadowingBuiltins
class Magic:
    def __init__(
        self, debug: bool = False, symlink: bool = False,
        compress: bool = False,
        devices: bool = False,
        mime_type: bool = False,
        mime_encoding: bool = False,
        all: bool = False,
        check: bool = False,
        preserve_atime: bool = False,
        raw: bool = False,
        error: bool = False,
        no_check_apptype: bool = False,
        no_check_ascii: bool = False,
        no_check_compress: bool = False,
        no_check_elf: bool = False,
        no_check_fortran: bool = False,
        no_check_soft: bool = False,
        no_check_tar: bool = False,
        no_check_tokens: bool = False,
        no_check_troff: bool = False
    ):
        """
        Open libmagic database and create a Magic instance


        :param debug: Print debugging messages to stderr.
        :param symlink: If the file queried is a symlink, follow it.
        :param compress: If the file is compressed, unpack it and look at the contents.
        :param devices: If the file is a block or character special
                        device, then open the device and try to look in its contents.
        :param mime_type: Return a MIME type string, instead of a textual description.
        :param mime_encoding: Return a MIME encoding, instead of a textual description.
        :param all: Return all matches, not just the first.
        :param check: Check the magic database for consistency and print warnings to stderr.
        :param preserve_atime: On systems that support utime or utimes, attempt to
                               preserve the access time of files analyzed.
        :param raw: Don't translate unprintable characters to a \\ooo octal representation.
        :param error: Treat operating system errors while trying to open files and
                      follow symlinks as real errors, instead of printing them
                      in the magic buffer.
        :param no_check_apptype: Check for EMX application type (only on EMX).
        :param no_check_ascii: Check for various types of ascii files.
        :param no_check_compress: Don't look for, or inside compressed files.
        :param no_check_elf: Don't print elf details.
        :param no_check_fortran: Don't look for fortran sequences inside ascii files.
        :param no_check_soft: Don't consult magic files.
        :param no_check_tar: Don't examine tar files.
        :param no_check_tokens: Don't look for known tokens inside ascii files.
        :param no_check_troff: Don't look for troff sequences inside ascii files.
        """

    def set_flags(
            self, debug: bool = False, symlink: bool = False,
            compress: bool = False,
            devices: bool = False,
            mime_type: bool = False,
            mime_encoding: bool = False,
            all: bool = False,
            check: bool = False,
            preserve_atime: bool = False,
            raw: bool = False,
            error: bool = False,
            no_check_apptype: bool = False,
            no_check_ascii: bool = False,
            no_check_compress: bool = False,
            no_check_elf: bool = False,
            no_check_fortran: bool = False,
            no_check_soft: bool = False,
            no_check_tar: bool = False,
            no_check_tokens: bool = False,
            no_check_troff: bool = False
    ) -> None:
        """
        Open libmagic database and create a Magic instance


        :param debug: Print debugging messages to stderr.
        :param symlink: If the file queried is a symlink, follow it.
        :param compress: If the file is compressed, unpack it and look at the contents.
        :param devices: If the file is a block or character special
                        device, then open the device and try to look in its contents.
        :param mime_type: Return a MIME type string, instead of a textual description.
        :param mime_encoding: Return a MIME encoding, instead of a textual description.
        :param all: Return all matches, not just the first.
        :param check: Check the magic database for consistency and print warnings to stderr.
        :param preserve_atime: On systems that support utime or utimes, attempt to
                               preserve the access time of files analyzed.
        :param raw: Don't translate unprintable characters to a \\ooo octal representation.
        :param error: Treat operating system errors while trying to open files and
                      follow symlinks as real errors, instead of printing them
                      in the magic buffer.
        :param no_check_apptype: Check for EMX application type (only on EMX).
        :param no_check_ascii: Check for various types of ascii files.
        :param no_check_compress: Don't look for, or inside compressed files.
        :param no_check_elf: Don't print elf details.
        :param no_check_fortran: Don't look for fortran sequences inside ascii files.
        :param no_check_soft: Don't consult magic files.
        :param no_check_tar: Don't examine tar files.
        :param no_check_tokens: Don't look for known tokens inside ascii files.
        :param no_check_troff: Don't look for troff sequences inside ascii files.
        """

    def load(self, db_path: Optional[str] = None) -> None:
        """
        Must be used to load the the colon separated list
        of database files passed in as filename, or None for the
        default database file before any magic queries can performed.

        :param db_path: filename or None for the default database
                        The default database file is named by the MAGIC
                        environment variable. If that variable is not set,
                        the default database file name is /usr/share/misc/magic.
                        magic_load() adds ".mgc" to the database filename
                        as appropriate.
        """

    def check(self, db_path: Optional[str] = None) -> bool:
        """
        Can be used to check the validity of entries in the
        colon separated database files passed in as filename, or None
        for the default database. It returns True on success and False on failure.

        :param db_path: filename or None for the default database
                        The default database file is named by the MAGIC
                        environment variable. If that variable is not set,
                        the default database file name is /usr/share/misc/magic.
                        magic_load() adds ".mgc" to the database filename
                        as appropriate.
        """

    def compile(self, db_path: Optional[str]) -> bool:
        """
        Can be used to compile the the colon separated list of database
        files passed in as filename, or None for the default database.
        It returns True on success and False on failure.
        The compiled files created are named from the basename of each file
        argument with ".mgc" appended to it.

        :param db_path: filename or None for the default database
                        The default database file is named by the MAGIC
                        environment variable. If that variable is not set,
                        the default database file name is "/usr/share/misc/magic".
                        magic_load() adds ".mgc" to the database filename
                        as appropriate.
        """

    def guess_file(self, filename: str) -> str:
        """
        Returns a textual description of the contents of the filename argument.
        """

    def guess_bytes(self, payload: bytes) -> str:
        """
        Returns a textual description of the contents of the bytes argument
        """



import os
from importlib.machinery import SourceFileLoader

from setuptools import Extension, setup


module_name = "cmagic"
module = SourceFileLoader(
    "version", os.path.join(module_name, "version.py"),
).load_module()


setup(
    name=module_name,
    version=module.__version__,
    ext_modules=[
        Extension(
            "{}._magic".format(module_name),
            ["cmagic/_magic.c"],
            libraries=["magic"],
            extra_compile_args=[],
        ),
    ],
    include_package_data=True,
    description=module.package_info,
    long_description=open("README.rst").read(),
    license=module.package_license,
    author=module.__author__,
    author_email=module.team_email,
    package_data={
        module_name: [
            "{}/_magic.pyi".format(module_name),
            "{}/py.typed".format(module_name),
        ],
    },
    project_urls={
        "Documentation": "https://github.com/mosquito/cmagic/",
        "Source": "https://github.com/mosquito/cmagic",
    },
    packages=[module_name],
    classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Operating System :: MacOS",
        "Operating System :: POSIX",
        "Operating System :: Microsoft",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    python_requires=">=3.5.*, <4",
    extras_require={
        "develop": [
            "pytest",
            "pytest-cov",
        ],
    },
)
